@@ -4,9 +4,9 @@ gencode_tracking_system:::sources::tab_file
 
 =head1 DESCRIPTION
 
-Helper script for the GENCODE tracking system, to be run nightly.
+Helper script for the GENCODE tracking system.
 
-Read tabl-delimited file, store in internal tracking system db
+Read tab-delimited file, store in internal tracking system db
 
  example:
    AK094771	21	36399049	36403858	Missing, one EST support
@@ -39,12 +39,13 @@ our @EXPORT = qw( run_update );
 my ($tracking_dbh, $prepare_hash, $user_id, $category_id, $das_source);
 my $features    = 0;
 my $gene_status = 'new';
+my $updated;
 
 sub run_update {
   ($tracking_dbh, $prepare_hash, $user_id, $category_id, $das_source) = @_;
 
   #TODO: load dynamically
-  my $gene_type   = 'bidirectional regions';
+  my $gene_type   = 'new_genes';
 
   my $file        = $OTHER_SERVERS{$das_source}->{'file'};
   print STDERR "Using file $file\n";
@@ -82,7 +83,7 @@ sub run_update {
       print_element(\%gene);
     }
     $gene{'type'} = "gene";
-    $current_gene_id = store_features($tracking_dbh, $prepare_hash, \%gene, 'gene',
+    ($current_gene_id, $updated) = store_features($tracking_dbh, $prepare_hash, \%gene, 'gene',
 				      0, 0, $user_id, $category_id);
 
     #store transcript
@@ -90,7 +91,7 @@ sub run_update {
       print STDERR "TRANSCRIPT:\n";
       print_element(\%transcript);
     }
-    $current_transcript_id = store_features($tracking_dbh, $prepare_hash, \%transcript, 'transcript',
+    ($current_transcript_id, $updated) = store_features($tracking_dbh, $prepare_hash, \%transcript, 'transcript',
 					    $current_gene_id, 0, $user_id, $category_id);
 
     $features++;
