@@ -1,7 +1,7 @@
 
 =head1 NAME
 
-gencode_tracking_system / check_data
+gencode_tracking_system : check_data.pl
 
 =head1 DESCRIPTION
 
@@ -13,6 +13,10 @@ Some examples are given here.
 
 Explicitely set analysis to run below.
 
+TODO: Some generalization!
+
+=head1 SYNOPSIS
+
 
 =head1 CONTACT
 
@@ -56,7 +60,7 @@ my $ENSEMBL_new_cdnas = 0;
 my $HAVANA_overlaps   = 0;
 my $flagged_pseudos   = 0;
 my $MIT_CONGO         = 0;
-my $missed_ccds       = 1;
+my $missed_ccds       = 0;
 my $missed_hgnc       = 0;
 my $use_file          = 0;
 my $UCSC_retros       = 0;
@@ -92,8 +96,11 @@ my $flag_count = 0;
 &GetOptions(
 	    'file:s'         => \$file,
 	    'analysis:s'     => \$analysis_to_run,
+	    'write!'         => \$WRITE,
+	    'env=s'          => \$ENVI,
 	   );
 
+gencode_tracking_system::config->set_databases();
 
 #connect to tracking system db
 my $tracking_dbh = connect_db($DBHOST, $DBPORT, $DBNAME, $DBUSER, $DBPASS)
@@ -165,7 +172,7 @@ if($HAVANA_overlaps){
   print STDERR "Set $flag_count new flags.\n";
 }
 if($flagged_pseudos){
-  $flag_count = check_flagged_pseudos('yale_flaggedpseudogenes', 'flagged_pseudogene');
+  $flag_count = check_category('yale_flaggedpseudogenes', 'flagged_pseudogene');
   print STDERR "Set $flag_count new flags.\n";
 }
 if($MIT_CONGO){
@@ -173,7 +180,7 @@ if($MIT_CONGO){
   print STDERR "Set $flag_count new flags.\n";
 }
 if($missed_ccds){
-  $flag_count = check_flagged_pseudos('missing_ccds', 'missing_ccds');
+  $flag_count = check_category('missing_ccds', 'missing_ccds');
   print STDERR "Set $flag_count new flags.\n";
 }
 if($missed_hgnc){
@@ -189,7 +196,7 @@ if($UCSC_retros){
   print STDERR "Set $flag_count new flags.\n";
 }
 if($CRG_U12){
-  $flag_count = check_flagged_pseudos('crg_u12', 'u12');
+  $flag_count = check_category('crg_u12', 'u12');
   print STDERR "Set $flag_count new flags.\n";
 }
 if($manual_hgnc){
@@ -210,9 +217,9 @@ print STDERR "\nDONE\n";
 
 ###############
 
-#add flags for pseudogene set to be checked by HAVANA
-sub check_flagged_pseudos {
-  my ($das_source, $flag_name) = @_;
+#add flags for category specified
+sub check_category {
+  my ($category_name, $flag_name) = @_;
 
   my $flag_count = 0;
   $statuses = $status_new.", ".$status_updated;
@@ -222,15 +229,15 @@ sub check_flagged_pseudos {
 
   reset_seen_flags($tracking_dbh, "flags", $flag_name);
 
-  my $other_category_id = get_category_id( $OTHER_SERVERS{$das_source}->{'category'}, $tracking_dbh );
+  my $other_category_id = get_category_id( $OTHER_SERVERS{$category_name}->{'category'}, $tracking_dbh );
   if(!$other_category_id){
-    die "Could not find category for ".$OTHER_SERVERS{$das_source}->{'category'}."\n";
+    die "Could not find category for ".$OTHER_SERVERS{$category_name}->{'category'}."\n";
   }
 
-  print STDERR "Looking for $das_source ($other_category_id) issues [$statuses].\n"  if($VERBOSE);
+  print STDERR "Looking for $category_name ($other_category_id) issues [$statuses].\n"  if($VERBOSE);
   my ($issues, $fields) = get_issues($tracking_dbh, undef, undef, undef, undef, $other_category_id, $statuses);
 
-  print STDERR "HAVE ".(scalar @$issues)."\n";
+  print STDERR "HAVE ".(scalar @$issues)." for $category_name\n";
 
   for(my $i=0; $i< scalar @$issues; $i++){
     my $issue = $issues->[$i];
@@ -259,8 +266,6 @@ sub check_flagged_pseudos {
       $flag_count++;
     }
     print STDERR "\n" if($VERBOSE);
-
-    #last if($flag_count>10);
   }
 
   analyse_seen_flags($tracking_dbh, "flags", $flag_name, $user_id);
@@ -594,7 +599,8 @@ sub check_affected_transcripts {
 	}
 	if($set_flag){
 	  #set tag / write flag
-	  print STDERR "  Setting flag $flag_name ($id_to_flag) from ".$issue->{'transcript_id'}." to ".$existing_transcripts->{'id'}.".\n" if($VERBOSE);
+	  print STDERR "  Setting flag $flag_name ($id_to_flag) from ".$issue->{'transcript_id'}." to ".
+	    $existing_transcripts->{'id'}.".\n" if($VERBOSE);
 	  if($WRITE){
 	    my $flag_id = set_flag($tracking_dbh, $existing_transcripts->{'id'}, $flag_name,
 				   undef, $user_id, $issue->{'transcript_id'});
