@@ -45,6 +45,8 @@ my $category  = "Ensembl";
 my ($gene_id, $transcript_id);
 my ($gene, $transcript, $flag, $details);
 my $flag_count = 0;
+#for the gene level: get only the canonical transcript instead of all transcripts?
+my $canonical = 1;
 
 &GetOptions(
 	    'gene=s'       => \$gene_id,
@@ -53,6 +55,8 @@ my $flag_count = 0;
 	    'category=s'   => \$category,
 	    'flag=s'       => \$flag,
 	    'note=s'       => \$details,
+	    'env=s'        => \$ENVI,
+	    'write!'       => \$WRITE,
 	   );
 
 if(!($gene_id or $transcript_id)){
@@ -60,6 +64,8 @@ if(!($gene_id or $transcript_id)){
   exit;
 }
 
+gencode_tracking_system::config->set_databases();
+
 #connect to tracking system db
 my $tracking_dbh = connect_db($DBHOST, $DBPORT, $DBNAME, $DBUSER, $DBPASS)
   or die "cant connect to to database $DBNAME @ $DBHOST.\n";
@@ -90,13 +96,29 @@ if($gene_id){
   #insert gene
   my $g_id = insert_object($gene, 'gene', 0, $gene_id);
 
-  #insert all transcripts of this gene
   my $t_id;
-  foreach my $transcript (@{$gene->get_all_Transcripts}){
+  my @transcripts = ();
+  if($canonical){
+    #insert only canonical transcript
+    my $t = $gene->canonical_transcript();
+    if(!$t){
+      push(@transcripts, $gene->get_all_Transcripts->[0]);
+    }
+    else{
+      push(@transcripts, $t);
+    }
+  }
+  else{
+    #insert all transcripts of this gene
+    @transcripts = @{$gene->get_all_Transcripts};
+  }
+
+  foreach my $transcript (@transcripts){
     $t_id = insert_object($transcript, 'transcript', $g_id, $gene->stable_id);
 
     if($flag){
       set_flag_on_transcript($t_id, $flag, $details);
+      #print "Z\t".$gene->stable_id."\t$t_id\t$flag\t$details\n";
     }
 
     #insert all exons of this transcript
@@ -240,4 +262,6 @@ sub check_phase{
 
 __END__
 
+read in ENSEMBL & CCDS ids to insert & flag:
+awk '{print "perl ~/1_cvs/gencode/tracking_system/perl/scripts/import_from_ensembl.pl -user Felix -category Ensembl -flag review_ccds -transcript "$1" -note "$2}' ccds_for_withdrawel.human
 
