@@ -57,20 +57,28 @@ my $use_secondary_id   = 0;
 my $check_biotype      = 0;
 my $has_header_row     = 0;
 my $dont_check_details = 0;
+my $write_details_as_history = 0;
+my $history_details;
 
 # ignore these biotypes if desired
 #my $avoid_types = '^(pseudogene|retrotransposed|processed_pseudogene|transcribed_processed_pseudogene|transcribed_unprocessed_pseudogene|IG_pseudogene|TR_pseudogene|unitary_pseudogene|unprocessed_pseudogene|artifact|IG_gene)$';
 my $avoid_types = '^(.*pseudogene|retrotransposed|artifact|IG_gene|tec)$';
 
 &GetOptions(
-	    'file=s'              => \$infile,
-	    'check_biotype!'      => \$check_biotype,
-	    'secondary_id!'       => \$use_secondary_id,
-	    'username=s'          => \$user_name,
-	    'test!'               => \$test,
-	    'has_header_row!'     => \$has_header_row,
-	    'dont_check_details!' => \$dont_check_details,
-	   );
+						'file=s'              => \$infile,
+						'check_biotype!'      => \$check_biotype,
+						'secondary_id!'       => \$use_secondary_id,
+						'username=s'          => \$user_name,
+						'test!'               => \$test,
+						'has_header_row!'     => \$has_header_row,
+						'dont_check_details!' => \$dont_check_details,
+						'details_as_history!' => \$write_details_as_history,
+						'env=s'               => \$ENVI,
+						'verbose!'            => \$VERBOSE,
+						'write!'              => \$WRITE,
+					 );
+
+gencode_tracking_system::config->set_databases();
 
 #connect to tracking system db
 my $tracking_dbh = connect_db($DBHOST, $DBPORT, $DBNAME, $DBUSER, $DBPASS);
@@ -114,6 +122,14 @@ while ($line = <IN>){
   $details = "" if(!$details);
   $details =~ s/\"//g;
 
+	if($write_details_as_history){
+		$history_details = $details;
+		$details = "";
+	}
+	else{
+		$history_details = undef;
+	}
+
   #optionally get secondary id
   if(!($transcript_id =~ /OTT/) and $use_secondary_id){
     $use_id = get_secondary_id($transcript_id, $prepare_hash);
@@ -159,25 +175,25 @@ while ($line = <IN>){
     else{
     #compare details (notes) of flags
       foreach my $flag (@$flags){
-	my $note1 = $flag->{'note'};
-	$note1 = "" if(!$note1);
-	my $note2 = $details;
-	# ignore whitespace differences between two flags
-	$note1 =~ s/\s//g; $note2 =~ s/\s//g;
+				my $note1 = $flag->{'note'};
+				$note1 = "" if(!$note1);
+				my $note2 = $details;
+				# ignore whitespace differences between two flags
+				$note1 =~ s/\s//g; $note2 =~ s/\s//g;
+				
+				#hack for changed (splice) notes
+				#$note2 =~ m/(.+;.+;.+);.+/g;
+				#$note2 = $1;
+				$note1 =~ s/\(.+\)//;
 
-	#hack for changed (splice) notes
-	#$note2 =~ m/(.+;.+;.+);.+/g;
-	#$note2 = $1;
-	$note1 =~ s/\(.+\)//;
+				print "Comparing notes\n$note1\n===\n$note2\n" if($VERBOSE);
 
-	print "Comparing $note1===$note2:".($note1 eq $note2)."\n" if($VERBOSE);
-
-	if(($flag->{'flag_name'} eq $flag_name) and ($note1 eq $note2)){
-	  set_seen_flag($prepare_hash, $flag->{'id'}, "flag", "2");
-	  print " Set seen:".($flag->{'id'})."\n" if($VERBOSE);
-	  $set_flag = 0;
-	}
-      }
+				if(($flag->{'flag_name'} eq $flag_name) and ($note1 eq $note2)){
+					set_seen_flag($prepare_hash, $flag->{'id'}, "flag", "2");
+					print " Set seen:".($flag->{'id'})."\n" if($VERBOSE);
+					$set_flag = 0;
+				}
+			}
     }
     print STDERR "  Found existing flag $flag_name.\n" if($VERBOSE);
   }
@@ -185,8 +201,8 @@ while ($line = <IN>){
 
     #set tag / write flag!
     print STDERR "  Setting flag $flag_name to ".$issue->{'name'}." / ".$issue->{'id'}." ($details).\n" if($VERBOSE);
-    if($WRITE){ set_flag($tracking_dbh, $issue->{'id'}, $flag_name, undef,
-			 $user_id, undef, $details); }
+    if($WRITE){ set_flag($tracking_dbh, $issue->{'id'}, $flag_name, 0,
+			 $user_id, undef, $details, $history_details); }
 
     $flag_count++;
   }
