@@ -57,8 +57,10 @@ my $use_priority_exceptions_from_db = 1;
 	    'verbose!'         => \$VERBOSE,
 	    'write!'           => \$WRITE,
 	    'exception-list=s' => \$exception_file,
+	    'env=s'            => \$ENVI,
 	   );
 
+gencode_tracking_system::config->set_databases();
 
 #connect to tracking system db
 $tracking_dbh = connect_db($DBHOST, $DBPORT, $DBNAME, $DBUSER, $DBPASS)
