@@ -16,8 +16,8 @@ config.action_controller.perform_caching             = false
 config.action_mailer.raise_delivery_errors = false
 
 # for the graphs plugin
-#config.cache_classes     = true
-#config.action_controller.perform_caching             = true
+config.cache_classes     = true
+config.action_controller.perform_caching             = true
 
 # AnnoTrack-specific settings
 REGISTRY = {}
